@@ -80,7 +80,7 @@ cc_gbif <- function(x,
     # Make SpatialPolygons out of the list of coordinates
     lst <- lapply(lst, as.matrix)
     ref <- sapply(lst, terra::vect, crs = wgs84, type = "polygons")
-    ref <- Reduce(rbind, ref)
+    ref <- terra::vect(ref)
     
     #point in polygon test
     ext_dat <- terra::extract(ref, dat)
